# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "Home" => "index.md",
    "output_saving.md",
    "integrating.md",
    "timed_callbacks.md",
    "steady_state.md",
    "step_control.md",
    "projection.md",
    "uncertainty_quantification.md",
]
